clear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compare suboptimal and optimal monetary policy
% in a model with sticky prices and wages
% The model uses Rotemberg-style contracts
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% model with suboptimal rule
!dynare++ --prefix f0 --per 20 stickyrotw.mod

% model with optimal Ramsey policy
!dynare++ --prefix f1 --per 20 stickyrotwramsey.mod  

% model with no nominal rigidities
!dynare++ --prefix f2 --per 20 growthmodel.mod

% number of periods for IRFs.
nperiods = 20;

%%%% Make figure to compare simulations
load stickyrotw
dset = 'f0';
mkirf

load stickyrotwramsey
dset = 'f1';        
mkirf

load growthmodel
dset = 'f2';        
mkirf


titlelist = char('Output','Capital (next period)','Investment','Labor','Consumption','Wage Inflation');
legendlist = char('Suboptimal Rule','Optimal Rule','Flex Price/Wage');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f0_gdp_irf/f0_gdp; f0_kp_irf/f0_kp; f0_ip_irf/f0_ip; f0_le_irf/f0_le; f0_cc_irf/f0_cc; f0_dw_irf*4]',...
          100*[f1_gdp_irf/f1_gdp; f1_kp_irf/f1_kp; f1_ip_irf/f1_ip; f1_le_irf/f1_le; f1_cc_irf/f1_cc; f1_dw_irf*4]',...
          100*[f2_gdp_irf/f2_gdp; f2_kp_irf/f2_kp; f2_ip_irf/f2_ip; f2_le_irf/f2_le; f2_cc_irf/f2_cc; nan*f1_dw_irf*4]')

      
titlelist = char('Inflation (AR)','Nominal Interest Rate (AR)','Real Ex-ante Rate (AR)');
legendlist = char('Suboptimal Rule','Optimal Rule');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[ f0_dp_irf*4; f0_rs_irf*4; f0_rs1_irf*4]', ...
          100*[ f1_dp_irf*4; f1_rs_irf*4; f1_rs1_irf*4]')  